﻿using UnityEngine;
using System.Collections;

public class FloorTileScript : MonoBehaviour {
	
	public bool working;
	public float limit; //minimum y-coordinate tile will fall to before being destroyed
	public float timeout; //time before tile is destroyed
	public Material colourChange; //colour tile will become when hit

	IEnumerator Timer () {

		renderer.material = colourChange; //changes tile colour
		yield return new WaitForSeconds (timeout); //waits certain amount of time...
		Rigidbody rigidBody = gameObject.AddComponent<Rigidbody> (); //...then adds a rigid body so physics can be applied
		audio.Play ();
		yield return new WaitForSeconds (audio.clip.length);
		
	}
	
	// Use this for initialization
	void Start () {

		working = true;

	}
	
	// Update is called once per frame
	void Update () {
		
		if (transform.position.y < limit) { //if the tile falls past this point...
			Destroy (gameObject); //...the tile is destroyed
		}
	
	}
	
	void OnTriggerEnter (Collider other) {
		
		if (other.gameObject.tag == "Player") { //detects if player hits tile
			
			Debug.Log (other.gameObject.name + " Beginning wave");
			DestructoWave (); //begins proceedings
			
		}

	}
	
	void DestructoWave () {

		if (working == true) {
			StartCoroutine (Timer ()); //starts coroutine to colour change and destroy
		}
		
	}

	void OnCollisionExit (Collision col) {

		if (col.gameObject.tag == "tile") { //detects if a tile has gone

			Debug.Log ("Beginning chain reaction");
			DestructoWave (); //begins proceedings in adjacent tiles

		}

	}

}
